@@ -37,12 +37,17 @@ def assume_role(role_name):
     os.environ['AWS_PROFILE'] = config.get_profile()
     if role and role.get('arn', None):
         client = get_sts_client()
-        assumed_role = client.assume_role(
-            RoleArn=role['arn'],
-            RoleSessionName=role_name
-        )
-        set_credentials(assumed_role['Credentials'])
-        set_region(role.get('region', 'us-east-1'))
+        try:
+            assumed_role = client.assume_role(
+                RoleArn=role['arn'],
+                RoleSessionName=role_name
+            )
+            set_credentials(assumed_role['Credentials'])
+            set_region(role.get('region', 'us-east-1'))
+        except ClientError as error:
+            if error.response['Error']['Code'] == 'ExpiredToken':
+                print(error)
+                exit(2)
     else:
         raise KeyError(f'Unable to find role {role_name}')
 
